import * as Platform from '@nativescript/core/platform';
import { StackLayout, Application as app, Color, Label } from '@nativescript/core';
export class ParallaxUtilities {
    static setMinimumHeight(contentView, anchoredRow, minHeight, includesAnchored) {
        if (includesAnchored) {
            minHeight = minHeight - (anchoredRow.getMeasuredHeight() * 0.9);
        }
        contentView.minHeight = minHeight;
    }
    static getMinimumHeights() {
        let height1 = Platform.Screen.mainScreen.heightDIPs;
        let height2 = Platform.Screen.mainScreen.widthDIPs;
        if (height1 > height2) {
            return {
                portrait: height1,
                landscape: height2
            };
        }
        else {
            return {
                portrait: height2,
                landscape: height1
            };
        }
    }
    static addDropShadow(translateY, width) {
        let wrapper = new StackLayout();
        wrapper.width = width;
        wrapper.height = 3;
        wrapper.translateY = translateY;
        wrapper.addChild(this.shadowView(0.4, width));
        wrapper.addChild(this.shadowView(0.2, width));
        wrapper.addChild(this.shadowView(0.05, width));
        return wrapper;
    }
    static shadowView(opacity, width) {
        let shadowRow = new StackLayout();
        shadowRow.backgroundColor = new Color('black');
        shadowRow.opacity = opacity;
        shadowRow.height = 1;
        return shadowRow;
    }
    static fadeViews(topHeight, verticalOffset, viewsToFade, topOpacity) {
        if (verticalOffset < topHeight) {
            topOpacity = parseFloat((1 - (verticalOffset * 0.01)).toString());
            if (topOpacity > 0 && topOpacity <= 1) {
                for (var v = 0; v < viewsToFade.length; v++) {
                    var view = viewsToFade[v];
                    view.opacity = topOpacity;
                }
            }
        }
    }
    static getAnchoredTopHeight(topHeight, verticalOffset) {
        let translateY;
        if (verticalOffset <= topHeight) {
            translateY = topHeight - (verticalOffset * 2);
            if (translateY > topHeight) {
                translateY = topHeight;
            }
            if (app.android) {
                translateY = translateY - 5;
            }
        }
        else {
            translateY = 0;
        }
        if (translateY < 0) {
            translateY = 0;
        }
        return translateY;
    }
    static getTopViewHeight(topHeight, verticalOffset) {
        if ((topHeight - verticalOffset) >= 0) {
            return topHeight - verticalOffset;
        }
        else {
            return 0;
        }
    }
    static displayDevWarning(parent, message, ...viewsToCollapse) {
        let warningText = new Label();
        warningText.text = message;
        warningText.color = new Color('red');
        warningText.textWrap = true;
        warningText.translateY = 50;
        parent.addChild(warningText);
        viewsToCollapse.forEach((view) => {
            if (view != null) {
                view.visibility = 'collapse';
            }
        });
    }
    static pluckViews(parent) {
        let returnViews = [];
        parent.eachLayoutChild((child) => {
            returnViews.push(child);
        });
        parent.removeChildren();
        return returnViews;
    }
    static containsCssClass(view, className) {
        const cssClasses = view.className.split(' ');
        return cssClasses.indexOf(className) > -1 ? true : false;
    }
}
//# sourceMappingURL=utilities.js.map